@@ -3,6 +3,7 @@ from typing import Any, Dict, List, Optional, Tuple  # noqa: F401
 
 import envo  # noqa: F401
 from envo import (  # noqa: F401
+    Env,
     Plugin,
     VirtualEnv,
     boot_code,
@@ -19,7 +20,6 @@ from envo import (  # noqa: F401
     postcmd,
     precmd,
     run,
-    Env
 )
 
 
